#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.tps_interfaces.associated_ref_frame import AssociatedRefFrame
from pycatia.tps_interfaces.composite_tolerance import CompositeTolerance
from pycatia.tps_interfaces.controlled_radius import ControlledRadius
from pycatia.tps_interfaces.datum_simple import DatumSimple
from pycatia.tps_interfaces.datum_target import DatumTarget
from pycatia.tps_interfaces.default_annotation import DefaultAnnotation
from pycatia.tps_interfaces.dimension_3d import Dimension3D
from pycatia.tps_interfaces.dimension_limit import DimensionLimit
from pycatia.tps_interfaces.dimension_pattern import DimensionPattern
from pycatia.tps_interfaces.envelope_condition import EnvelopeCondition
from pycatia.tps_interfaces.flag_note import FlagNote
from pycatia.tps_interfaces.free_state import FreeState
from pycatia.tps_interfaces.material_condition import MaterialCondition
from pycatia.tps_interfaces.noa import Noa
from pycatia.tps_interfaces.particular_tol_elem import ParticularTolElem
from pycatia.tps_interfaces.projected_tolerance_zone import ProjectedToleranceZone
from pycatia.tps_interfaces.reference_frame import ReferenceFrame
from pycatia.tps_interfaces.roughness import Roughness
from pycatia.tps_interfaces.shifted_profile_tolerance import ShiftedProfileTolerance
from pycatia.tps_interfaces.tangent_plane import TangentPlane
from pycatia.tps_interfaces.text import Text
from pycatia.tps_interfaces.tolerance_per_unit_basis_restrictive_value import TolerancePerUnitBasisRestrictiveValue
from pycatia.tps_interfaces.tolerance_unit_basis_value import ToleranceUnitBasisValue
from pycatia.tps_interfaces.tolerance_zone import ToleranceZone
from pycatia.tps_interfaces.tps_view import TPSView


class Annotation(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Annotation
                | 
                | Interface for the Technological Product Specification (TPS)
                | objects.
                | Leaf entity in the Design Pattern Composite. TPS modeler enables definition of
                | specification related to surfaces.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.annotation = com_object

    @property
    def super_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SuperType() As CATBSTR (Read Only)
                | 
                |     Get the Super Type.
                | 
                |     Parameters:
                | 
                |         oSuperType
                |             The Super Type. The list of SuperType available: "FTA_NonSemantic"
                |             "FTA_Form" "FTA_Dimension" "FTA_Position" "FTA_Datum" "FTA_Orientation"
                |             "FTA_RunOut"

        :return: str
        :rtype: str
        """

        return self.annotation.SuperType

    @property
    def tps_status(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TPSStatus() As CATBSTR (Read Only)
                | 
                |     Get the TPS Status.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             The Status.

        :return: str
        :rtype: str
        """

        return self.annotation.TPSStatus

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Get the Type.
                | 
                |     Parameters:
                | 
                |         oType
                |             The Type. List of types available ordered by SuperType: SuperType = "FTA_NonSemantic" Type = "FTA_Text" Type = "FTA_FlagNote" Type = "FTA_Roughness" Type = "FTA_Weld" Type = "FTA_Noa" Type = "FTA_NonSemanticDatum" Type = "FTA_NonSemanticTarget" Type = "FTA_NonSemanticGDT" Type = "FTA_NonSemanticDimension" SuperType = "FTA_Form" Type = "FTA_Flatness" Type = "FTA_Straightness" Type = "FTA_Circularity" Type = "FTA_Cylindricity" Type = "FTA_ProfileOfAnyLine" Type = "FTA_ProfileOfASurface" Type = "FTA_PatternTruePos" SuperType = "FTA_Dimension" Type = "FTA_LinearDimension" Type = "FTA_AngularDimension" Type = "FTA_SecondLinearDimension" Type = "FTA_ChamferDimension" Type = "FTA_BasicDimension" SuperType = "FTA_Position" Type = "FTA_TruePosition" Type = "FTA_Concentricity" Type = "FTA_Symmetry" Type = "FTA_PositionOfAnyLine" Type = "FTA_PositionOfASurface" SuperType = "FTA_Datum" Type = "FTA_DatumSimple" Type = "FTA_DatumTarget" Type = "FTA_DatumSystem" Type = "FTA_ReferenceFrame" SuperType = "FTA_Orientation" Type = "FTA_Parallelism" Type = "FTA_Perpendicularity" Type = "FTA_Angularity" SuperType = "FTA_RunOut" Type = "FTA_TotalRunOut" Type = "FTA_CircularRunOut"

        :return: str
        :rtype: str
        """

        return self.annotation.Type

    @property
    def z(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Z(double iZ) (Write Only)
                | 
                |     method get_Z will never be exposed Set the offset of the
                |     annotation
                | 
                |     Parameters:
                | 
                |         iZ
                |             The offset.

        :return: float
        :rtype: float
        """

        return self.annotation.Z

    @z.setter
    def z(self, value: float):
        """
        :param float value:
        """

        self.annotation.Z = value

    def add_leader(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddLeader()
                | 
                |     Add a leader.

        :return: None
        :rtype: None
        """
        return self.annotation.AddLeader()

    def apply_referenced_geom_colour(self, i_releated_r: int, i_releated_g: int, i_releated_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyReferencedGeomColor(long iReleatedR,
                | long iReleatedG,
                | long iReleatedB)
                | 
                |     Apply a color to referenced geometry.

        :param int i_releated_r:
        :param int i_releated_g:
        :param int i_releated_b:
        :return: None
        :rtype: None
        """
        return self.annotation.ApplyReferencedGeomColor(i_releated_r, i_releated_g, i_releated_b)

    def apply_referenced_init_colour(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyReferencedInitColor()
                | 
                |     Apply the initial color to referenced geometry.

        :return: None
        :rtype: None
        """
        return self.annotation.ApplyReferencedInitColor()

    def associated_ref_frame(self) -> AssociatedRefFrame:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AssociatedRefFrame() As AssociatedRefFrame
                | 
                |     Get the annotation on the AssociatedRefFrame interface.

        :return: AssociatedRefFrame
        :rtype: AssociatedRefFrame
        """

        return AssociatedRefFrame(self.annotation.AssociatedRefFrame())

    def composite_tolerance(self) -> CompositeTolerance:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CompositeTolerance() As CompositeTolerance
                | 
                |     Get the annotation on the CompositeTolerance interface.

        :return: CompositeTolerance
        :rtype: CompositeTolerance
        """

        return CompositeTolerance(self.annotation.CompositeTolerance())

    def controlled_radius(self) -> ControlledRadius:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ControledRadius() As ControledRadius
                | 
                |     Get the annotation on the ControledRadius interface.

        :return: ControledRadius
        :rtype: ControledRadius
        """

        return ControlledRadius(self.annotation.ControlledRadius())

    def datum_simple(self) -> DatumSimple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DatumSimple() As DatumSimple
                | 
                |     Get the annotation on the DatumSimple interface.

        :return: DatumSimple
        :rtype: DatumSimple
        """

        return DatumSimple(self.annotation.DatumSimple())

    def datum_target(self) -> DatumTarget:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DatumTarget() As DatumTarget
                | 
                |     Get the annotation on the DatumTarget interface.

        :return: DatumTarget
        :rtype: DatumTarget
        """

        return DatumTarget(self.annotation.DatumTarget())

    def default_annotation(self) -> DefaultAnnotation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DefaultAnnotation() As DefaultAnnotation
                | 
                |     Get the annotation on the DefaultAnnotation interface.

        :return: DefaultAnnotation
        :rtype: DefaultAnnotation
        """

        return DefaultAnnotation(self.annotation.DefaultAnnotation())

    def dimension_3d(self) -> Dimension3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Dimension3D() As Dimension3D
                | 
                |     Get the 3D Dimension on the 3D Dimension interface.
                | 
                |     Parameters:
                | 
                |         oDim
                |             The 3D Dimension.

        :return: Dimension3D
        :rtype: Dimension3D
        """

        return Dimension3D(self.annotation.Dimension3D())

    def dimension_limit(self) -> DimensionLimit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DimensionLimit() As DimensionLimit
                | 
                |     Get the annotation on the DimensionLimit interface.

        :return: DimensionLimit
        :rtype: DimensionLimit
        """

        return DimensionLimit(self.annotation.DimensionLimit())

    def dimension_pattern(self) -> DimensionPattern:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DimensionPattern() As DimensionPattern
                | 
                |     Get the annotation on the DimensionPattern interface.

        :return: DimensionPattern
        :rtype: DimensionPattern
        """

        return DimensionPattern(self.annotation.DimensionPattern())

    def envelop_condition(self) -> EnvelopeCondition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func EnvelopCondition() As EnvelopCondition
                | 
                |     Get the annotation on the EnvelopCondition interface.

        :return: EnvelopCondition
        :rtype: EnvelopCondition
        """

        return EnvelopeCondition(self.annotation.EnvelopeCondition())

    def flag_note(self) -> FlagNote:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FlagNote() As FlagNote
                | 
                |     Get the annotation on the FlagNote interface.
                | 
                |     Parameters:
                | 
                |         oFlagNote
                |             The annotation Flag Note.

        :return: FlagNote
        :rtype: FlagNote
        """

        return FlagNote(self.annotation.FlagNote())

    def free_state(self) -> FreeState:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FreeState() As FreeState
                | 
                |     Get the annotation on the FreeState interface.

        :return: FreeState
        :rtype: FreeState
        """

        return FreeState(self.annotation.FreeState())

    def get_surfaces(self, o_safe_array: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSurfaces(CATSafeArrayVariant oSafeArray)
                | 
                |     Get the geometry on which the Annotation is applied to.

        :param tuple o_safe_array:
        :return: tuple
        :rtype: tuple
        """
        return self.annotation.GetSurfaces(o_safe_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_surfaces'
        # # vba_code = """
        # # Public Function get_surfaces(annotation)
        # #     Dim oSafeArray (2)
        # #     annotation.GetSurfaces oSafeArray
        # #     get_surfaces = oSafeArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_surfaces_count(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSurfacesCount() As double
                | 
                |     Count the geometry on which the Annotation is applied to.

        :return: float
        :rtype: float
        """
        return self.annotation.GetSurfacesCount()

    def has_a_controlled_radius(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAControledRadius() As boolean
                | 
                |     To know if the Annotation has a Controled Radius.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasAControledRadius()

    def has_a_free_state(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAFreeState() As boolean
                | 
                |     To know if the Annotation has a Free State.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasAFreeState()

    def has_a_material_condition(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAMaterialCondition() As boolean
                | 
                |     To know if the Annotation has a Material Condition.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasAMaterialCondition()

    def has_a_particular_tol_elem(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAParticularTolElem() As boolean
                | 
                |     To know if the Annotation has a Particuler Element.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasAParticularTolElem()

    def has_a_tolerance_per_unit_basis_restrictive_value(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasATolerancePerUnitBasisRestrictiveValue() As boolean
                | 
                |     To know if the Annotation has a Tolerance Per Unit Basis Restricted Value.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasATolerancePerUnitBasisRestrictiveValue()

    def has_an_envelop_condition(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasAnEnvelopCondition() As boolean
                | 
                |     To know if the Annotation has an Envelop Condition.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasAnEnvelopCondition()

    def has_dimension_limit(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasDimensionLimit() As boolean
                | 
                |     To know if the Annotation has a Dimension Limit.

        :return: bool
        :rtype: bool
        """
        return self.annotation.HasDimensionLimit()

    def is_a_composite_tolerance(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsACompositeTolerance() As boolean
                | 
                |     To know if the Annotation is a composite Tolerance.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsACompositeTolerance()

    def is_a_default_annotation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsADefaultAnnotation() As boolean
                | 
                |     To know if the Annotation is a Default Annotation.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsADefaultAnnotation()

    def is_a_dimension_pattern(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsADimensionPattern() As boolean
                | 
                |     To know if the Annotation is a Dimension Pattern.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsADimensionPattern()

    def is_a_projected_tolerance_zone(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAProjectedToleranceZone() As boolean
                | 
                |     To know if the Annotation is a Projected Zone.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsAProjectedToleranceZone()

    def is_a_shifted_profile_tolerance(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAShiftedProfileTolerance() As boolean
                | 
                |     To know if the Annotation is a Shifted Profile Tolerance.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsAShiftedProfileTolerance()

    def is_a_tangent_plane(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsATangentPlane() As boolean
                | 
                |     To know if the Annotation is a Tangent Plane.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsATangentPlane()

    def is_a_tolerance_unit_basis_value(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAToleranceUnitBasisValue() As boolean
                | 
                |     To know if the Annotation is a Tolerance Unit Basis Value.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsAToleranceUnitBasisValue()

    def is_a_tolerance_zone(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAToleranceZone() As boolean
                | 
                |     Is the a Tolerance Zone.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsAToleranceZone()

    def is_an_associated_ref_frame(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAnAssociatedRefFrame() As boolean
                | 
                |     To know if the Annotation is an Associated Reference Frame.

        :return: bool
        :rtype: bool
        """
        return self.annotation.IsAnAssociatedRefFrame()

    def material_condition(self) -> MaterialCondition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func MaterialCondition() As MaterialCondition
                | 
                |     Get the annotation on the MaterialCondition interface.

        :return: MaterialCondition
        :rtype: MaterialCondition
        """

        return MaterialCondition(self.annotation.MaterialCondition())

    def modify_visualisation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ModifyVisu()
                | 
                |     To refresh the 3D visualization.

        :return: None
        :rtype: None
        """
        return self.annotation.ModifyVisu()

    def noa(self) -> Noa:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Noa() As Noa
                | 
                |     Get the annotation on the Noa interface.

        :return: Noa
        :rtype: Noa
        """

        return Noa(self.annotation.Noa())

    def particular_tol_elem(self) -> ParticularTolElem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ParticularTolElem() As ParticularTolElem
                | 
                |     Get the annotation on the ParticularTolElem interface.

        :return: ParticularTolElem
        :rtype: ParticularTolElem
        """

        return ParticularTolElem(self.annotation.ParticularTolElem())

    def projected_tolerance_zone(self) -> ProjectedToleranceZone:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ProjectedToleranceZone() As ProjectedToleranceZone
                | 
                |     Get the annotation on the ProjectedToleranceZone interface.

        :return: ProjectedToleranceZone
        :rtype: ProjectedToleranceZone
        """
        return ProjectedToleranceZone(
            self.annotation.ProjectedToleranceZone())

    def reference_frame(self) -> ReferenceFrame:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ReferenceFrame() As ReferenceFrame
                | 
                |     Get the annotation on the ReferenceFrame interface.

        :return: ReferenceFrame
        :rtype: ReferenceFrame
        """

        return ReferenceFrame(self.annotation.ReferenceFrame())

    def roughness(self) -> Roughness:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Roughness() As Roughness
                | 
                |     Get the annotation on the Roughness interface.

        :return: Roughness
        :rtype: Roughness
        """

        return Roughness(self.annotation.Roughness())

    def set_xy(self, i_x: float, i_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetXY(double iX,
                | double iY)
                | 
                |     method GetXY will never be exposed Set TPS coordinates in the
                |     view
                | 
                |     Parameters:
                | 
                |         oX
                |             The X coordinate. 
                |         oY
                |             The Y coordinate.

        :param float i_x:
        :param float i_y:
        :return: None
        :rtype: None
        """
        return self.annotation.SetXY(i_x, i_y)

    def shifted_profile_tolerance(self) -> ShiftedProfileTolerance:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ShiftedProfileTolerance() As ShiftedProfileTolerance
                | 
                |     Get the annotation on the ShiftedProfileTolerance interface.

        :return: ShiftedProfileTolerance
        :rtype: ShiftedProfileTolerance
        """

        return ShiftedProfileTolerance(self.annotation.ShiftedProfileTolerance())

    def tangent_plane(self) -> TangentPlane:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TangentPlane() As TangentPlane
                | 
                |     Get the annotation on the TangentPlane interface.

        :return: TangentPlane
        :rtype: TangentPlane
        """

        return TangentPlane(self.annotation.TangentPlane())

    def text(self) -> Text:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Text() As Text
                | 
                |     Get the annotation on the Text interface.
                | 
                |     Parameters:
                | 
                |         oText
                |             The annotation Text.

        :return: Text
        :rtype: Text
        """
        return Text(self.annotation.Text())

    def tolerance_per_unit_basis_restrictive_value(self) -> TolerancePerUnitBasisRestrictiveValue:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TolerancePerUnitBasisRestrictiveValue() As
                | TolerancePerUnitBasisRestrictiveValue
                | 
                |     Get the annotation on the TolerancePerUnitBasisRestrictiveValue interface.

        :return: TolerancePerUnitBasisRestrictiveValue
        :rtype: TolerancePerUnitBasisRestrictiveValue
        """
        return TolerancePerUnitBasisRestrictiveValue(self.annotation.TolerancePerUnitBasisRestrictiveValue())

    def tolerance_unit_basis_value(self) -> ToleranceUnitBasisValue:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ToleranceUnitBasisValue() As ToleranceUnitBasisValue
                | 
                |     Get the annotation on the ToleranceUnitBasisValue interface.

        :return: ToleranceUnitBasisValue
        :rtype: ToleranceUnitBasisValue
        """
        return ToleranceUnitBasisValue(self.annotation.ToleranceUnitBasisValue())

    def tolerance_zone(self) -> ToleranceZone:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ToleranceZone() As ToleranceZone
                | 
                |     Get the annotation on the ToleranceZone interface.

        :return: ToleranceZone
        :rtype: ToleranceZone
        """

        return ToleranceZone(self.annotation.ToleranceZone())

    def transfert_to_view(self, i_view: TPSView) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub TransfertToView(TPSView iView)
                | 
                |     Move the annotation in another view.
                | 
                |     Parameters:
                | 
                |         iView
                |             The destination view.

        :param TPSView i_view:
        :return: None
        :rtype: None
        """
        return self.annotation.TransfertToView(i_view.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'transfert_to_view'
        # # vba_code = """
        # # Public Function transfert_to_view(annotation)
        # #     Dim iView (2)
        # #     annotation.TransfertToView iView
        # #     transfert_to_view = iView
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Annotation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject


class SelectedElement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SelectedElement
                | 
                | Represents an element contained by a Selection object.
                | This object is an object contained by a Selection object. The Selection object
                | contains SelectedElement objects, which are accessed through the
                | Selection.Count2 and Selection.Item2 methods.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.selected_element = com_object

    @property
    def document(self) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Document() As Document (Read Only)
                | 
                |     Returns the document to which the selected element belongs.

        :return: Document
        :rtype: Document
        """

        return Document(self.selected_element.Document)

    @property
    def leaf_product(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LeafProduct() As AnyObject (Read Only)
                | 
                |     Returns the leaf product corresponding to the selection in the
                |     specification tree.
                |     Role: Returns the leaf Product (component, corresponding for example to
                |     "Product1.1" in the specification tree). The AnyObject returned is a Product if
                |     a product appears in the specification tree, in the path corresponding to the
                |     current selection, and a fake AnyObject whose AnyObject.Name property equals to
                |     "InvalidLeafProduct" otherwise.
                |     Cumulated with the use of the AnyObject.Parent property (which enables to
                |     navigate into the object structure), the current property enables the scripter
                |     to obtain the path, in the specification tree, corresponding to the
                |     selection.
                | 
                |     Example:
                | 
                |           The following example supposes a 
                | 
                |     Part or a Product is opened. It asks the end user to select a Shape in the
                |     current window. It then sends message boxes containing the names of the
                |     automation objects contained in the specification tree path corresponding to
                |     the shape selected, and, regarding the automation objects which are products
                |     (only products which are components), a message box containing the abcissa of
                |     the translation of the product compared to its reference
                |     product.
                | 
                |      Dim Status,Feature,LeafProduct,LeafProductProcessed,InputObjectType(0)
                |      Dim Document,Selection,AutomationTreeNodeOrProduct,Position,AxisComponentsArray(11)
                |      Set Document = CATIA.ActiveDocument : Set Selection = Document.Selection
                |     'We propose to the user that he select a feature
                |      InputObjectType(0)="AnyObject" 
                |      Status=Selection.SelectElement2(InputObjectType,"Select a
                |      feature",true)
                |      if (Status = "Cancel") then Exit Sub
                |      Set Feature = Selection.Item(1).Value
                |      Set LeafProduct = Selection.Item(1).LeafProduct
                |      LeafProductProcessed = true
                |      if (LeafProduct.Name<>"InvalidLeafProduct") then LeafProductProcessed = false
                |      Set AutomationTreeNodeOrProduct = Feature
                |      do while
                |      (TypeName(AutomationTreeNodeOrProduct)<>"Application")
                |     '  We send a message box, if AutomationTreeNodeOrProduct is not nor a
                |     Shapes object neither a PartDocument object
                |          if ((TypeName(AutomationTreeNodeOrProduct)<>"Shapes") And
                |          _
                |              (TypeName(AutomationTreeNodeOrProduct)<>"Bodies") And
                |              _
                |              (TypeName(AutomationTreeNodeOrProduct)<>"PartDocument") And
                |              _
                |              (TypeName(AutomationTreeNodeOrProduct)<>"Products") And
                |              _
                |              (TypeName(AutomationTreeNodeOrProduct)<>"ProductDocument"))
                |              then
                |              msgbox AutomationTreeNodeOrProduct.Name
                |              if (TypeName(AutomationTreeNodeOrProduct)="Product")
                |              then
                |     '          We display a message box containing the abcissa of the
                |     translation, except in the case of the
                |     '          root product
                |                  if
                |                  (TypeName(AutomationTreeNodeOrProduct.Parent.Parent)<>"Application")
                |                  then
                |                      Set Position = AutomationTreeNodeOrProduct.Position
                |                      Call Position.GetComponents(AxisComponentsArray)
                |                      msgbox AxisComponentsArray(9)
                |                  end if
                |              end if
                |          end if
                |     '  We determine the next automation tree node or product
                |          Set AutomationTreeNodeOrProduct = AutomationTreeNodeOrProduct.Parent
                |          if ((TypeName(AutomationTreeNodeOrProduct)="Application") And (Not
                |          LeafProductProcessed)) then
                |     '      The specification tree path corresponding to the selection contains
                |     at least one product, which the current
                |     '      loop as not yet processed. It means that the parent in the
                |     specification tree of the feature corresponding
                |     '      to the last message box sent is LeafProduct
                |              Set AutomationTreeNodeOrProduct = LeafProduct
                |              LeafProductProcessed = true
                |          end if
                |      loop
                | 
                |     If you run the preceeding piece of script, the current document beeing a
                |     product with the following specification tree:
                | 
                |          +--------+ 
                |          !Product3!
                |          +----+---+
                |               !
                |               +- Product2 (Product2.1)             'translation value:
                |               10
                |               !     !
                |               !     +- Product1 (Product1.1)       'translation value:
                |               20
                |               !           !
                |               !           +- Part1 (Part1.1)       
                |               !                !
                |               !                +- Part1
                |               !                     !
                |               !                     +- PartBody
                |               !                           !
                |               !                           +- Pad.1
                |               +- Part2 (Part2.1)
                | 
                |     and you select Pad.1, the message boxes displayed will be:
                | 
                |          Pad.1
                |          PartBody
                |          Part1
                |          Part1.1
                |          Product1.1
                |          20
                |          Product2.1
                |          10
                |          Product3

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.selected_element.LeafProduct)

    @property
    def reference(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Reference() As Reference (Read Only)
                | 
                |     Returns a Reference version of the Value property.
                |     Role: Returns a Reference version of Value .

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.selected_element.Reference)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the string constant which describes the selected element Automation
                |     type.
                |     This type is returned by the Value property, and may be, for instance "Pad"
                |     or "Line2D".
                |     Caution: This property gives the leaf automation type of the object, in the
                |     inheritance hierarchy. Nevertheless, after a call to Selection.SelectElement2 ,
                |     Selection.SelectElement3 , Selection.SelectElement4 ,
                |     Selection.IndicateOrSelectElement2D or Selection.IndicateOrSelectElement3D ,
                |     this property gives the input filter string constant relative to the effective
                |     selection (more precisely the first filter string constant delivered through
                |     the iFilterType parameter, for which the current automation object fullfills
                |     the string constant). This string constant may be an automation object name
                |     corresponding to the iFilterType parameter with which Selection.SelectElement2
                |     has previously been called, or even a CATSelectionFilter value
                |     name.
                | 
                |     Example:
                | 
                |           Suppose you run the following piece of script: 
                |          
                | 
                |          Set Selection = CATIA.ActiveDocument.Selection
                |         '  We propose to the user that he select a Prism or a
                |         Hole
                |          ReDim InputObjectType(1) : InputObjectType(0)="Prism" : InputObjectType(1)="Hole"
                |          Status=Selection.SelectElement2(InputObjectType,"Select a prism or a
                |          hole",true)
                |          if (Status = "Cancel") then Exit Sub
                |          AutomationType = Selection.Item(1).Type
                | 
                | 
                |          If the user selects a Pad, the script AutomationType variable will
                |          contain "Prism"
                |          and not "Pad".
                |          
                | 
                |         Consequently, in most cases, use the VBScript TypeName function instead
                |         of this property.

        :return: str
        :rtype: str
        """

        return self.selected_element.Type

    @property
    def value(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Value() As CATBaseDispatch (Read Only)
                | 
                |     Returns the actual selected automation object.

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.selected_element.Value)

    def get_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCoordinates(CATSafeArrayVariant ioPoint)
                | 
                |     Returns the coordinates of the pick point.
                | 
                |     Parameters:
                | 
                |         oPoint
                |             The coordinates of the pick point, i.e. the hit between the
                |             geometric object and the cursor.
                |             The length of this parameter will be 3, except if the document is a
                |             DrawingDocument
                |     Example:
                | 
                |           This example retrieves the coordinates of the pick point in
                |           the
                |          array myArray:
                | 
                |          Dim oSelElem As SelectedElement
                |          Set oSelElem = CATIA.ActiveDocument.Selection.Item(1)
                |          ReDim myArray(2)
                |          oSelElem.GetCoordinates myArray

        :param tuple io_point:
        :return: None
        :rtype: None
        """
        vba_function_name = 'get_coordinates'
        vba_code = """
        Public Function get_coordinates(selected_element)
            Dim ioPoint (2)
            selected_element.GetCoordinates ioPoint
            get_coordinates = ioPoint
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SelectedElement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import Iterator

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.tps_interfaces.annotation_set import AnnotationSet
from pycatia.types.general import cat_variant


class AnnotationSets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnnotationSets
                | 
                | Interface for collection of Annotations' Set
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.annotation_sets = com_object
        self.child_object = AnnotationSet

    def add_in_a_product(self, i_product: Product, i_standard: str) -> AnnotationSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddInAProduct(Product iProduct,
                | CATBSTR iStandard) As AnnotationSet
                | 
                |     Add a set in the product.

        :param Product i_product:
        :param str i_standard:
        :return: AnnotationSet
        :rtype: AnnotationSet
        """
        return AnnotationSet(self.annotation_sets.AddInAProduct(i_product.com_object, i_standard))

    def item(self, i_index: cat_variant) -> AnnotationSet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnyObject
                | 
                |     Retrieve a set.

        :param CATVariant i_index:
        :return: AnyObject
        :rtype: AnyObject
        """
        return AnnotationSet(self.annotation_sets.Item(i_index))

    def load_annotation_sets_list(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LoadAnnotationSetsList()
                | 
                |     Loads the Annotation Sets list. This method is very useful when a cgr
                |     document containing Annotation Set is inserted in the product, because the
                |     Annotation Set is not automatically loaded If the Annotation Set is already
                |     loaded nothing happens.

        :return: None
        :rtype: None
        """
        return self.annotation_sets.LoadAnnotationSetsList()

    def __getitem__(self, n: int) -> AnnotationSet:
        if (n + 1) > self.count:
            raise StopIteration

        return AnnotationSet(self.annotation_sets.item(n + 1))

    def __iter__(self) -> Iterator[AnnotationSet]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'AnnotationSets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.navigator_interfaces.marker_2Ds import Marker2Ds
from pycatia.system_interfaces.any_object import AnyObject


class AnnotatedView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnnotatedView
                | 
                | Represents an annotated view.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.annotated_view = com_object

    @property
    def behavior_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BehaviorMode() As CatAnnotatedViewBehavior
                | 
                |     Returns or sets the behavior mode of the annotated view. This behavior mode
                |     enables the annotated view to be independant from the
                |     viewpoint.
                | 
                |     Example:
                | 
                |              This example retrieves the behavior mode of the NewAnnotatedView
                |              annotated view.
                |             
                | 
                |             Dim Mode
                |             Mode = NewAnnotatedView.BehaviorMode

        :return: int
        :rtype: int
        """

        return self.annotated_view.BehaviorMode

    @behavior_mode.setter
    def behavior_mode(self, value: int):
        """
        :param int value:
        """

        self.annotated_view.BehaviorMode = value

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Comment() As CATBSTR
                | 
                |     Returns or sets the comment associated with the annotated
                |     view.
                | 
                |     Example:
                | 
                |              This example retrieves the comment of NewAnnotatedView annotated
                |              view.
                |             
                | 
                |             Dim text As String
                |             text = NewAnnotatedView.Comment

        :return: str
        :rtype: str
        """

        return self.annotated_view.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.annotated_view.Comment = value

    @property
    def field_of_view(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FieldOfView() As double (Read Only)
                | 
                |     Returns the field of view associated with the annotated view. The field of
                |     view is half of the vertical angle of the viewpoint, expressed in degrees. This
                |     property exists with the perspective (conic) projection mode
                |     only.
                | 
                |     Example:
                | 
                |              This example retrieves the field of view of the NewAnnotatedView
                |              annotated view.
                |             
                | 
                |             Dim Field As Double
                |             Field = NewAnnotatedView.FieldOfView

        :return: float
        :rtype: float
        """

        return self.annotated_view.FieldOfView

    @property
    def marker2_ds(self) -> Marker2Ds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker2Ds() As Marker2Ds (Read Only)
                | 
                |     Returns the Marker2D Collection associated with the annotated
                |     view.
                | 
                |     Example:
                | 
                |              This example retrieves the TheMarker2Ds
                |              collection
                |             from the NewAnnotatedView annotated view.
                |             
                | 
                |             Dim TheMarker2Ds As AnnotatedView
                |             Set TheMarker2Ds = NewAnnotatedView.Marker2Ds(9)

        :return: Marker2Ds
        :rtype: Marker2Ds
        """

        return Marker2Ds(self.annotated_view.Marker2Ds)

    @property
    def projection_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProjectionMode() As CatProjectionMode (Read Only)
                | 
                |     Returns the projection mode of the annotated view. This projection mode is
                |     the one of the associated 3D View point.
                | 
                |     Example:
                | 
                |              This example retrieves the projection mode of the NewAnnotatedView
                |              annotated view.
                |             
                | 
                |             Dim Mode
                |             Mode = NewAnnotatedView.ProjectionMode

        :return: int
        :rtype: int
        """

        return self.annotated_view.ProjectionMode

    @property
    def sound(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Sound() As CATBSTR
                | 
                |     Returns or sets the path of the sound file associated with the annotated
                |     view.
                | 
                |     Parameters:
                | 
                |         iPath
                |             The path of the sound file. If this path is not empty, the sound
                |             replaces the old associated one (if it exists) or creates a new association (if
                |             not). If this path is empty, the sound is removed.
                |             
                | 
                |     Returns:
                |         The path of the sound file. If this path is empty, the annotated view
                |         has no associated sound. 
                |     Example:
                | 
                |              This example retrieves the path of the sound file associated with
                |              the NewAnnotatedView annotated view.
                |             
                | 
                |             Dim path As String
                |             path = NewAnnotatedView.Sound

        :return: str
        :rtype: str
        """

        return self.annotated_view.Sound

    @sound.setter
    def sound(self, value: str):
        """
        :param str value:
        """

        self.annotated_view.Sound = value

    @property
    def zoom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Zoom() As double (Read Only)
                | 
                |     Returns the zoom factor associated with the annotated view. This property
                |     exists with the parallel (cylindric) projection mode only. This zoom factor is
                |     the one of the associated 3D View point.
                | 
                |     Example:
                | 
                |              This example retrieves in ZoomFactor the zoom of the
                |              NewAnnotatedView annotated view.
                |             
                | 
                |             Dim ZoomFactor As Double
                |             ZoomFactor = NewAnnotatedView.Zoom

        :return: float
        :rtype: float
        """

        return self.annotated_view.Zoom

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Retrieves the coordinates of the origin of the 3D viewpoint of the
                |     annotated view.
                | 
                |     Parameters:
                | 
                |         oOrigin
                |             The coordinates of the view point origin expressed as an array of 3
                |             variants are:
                | 
                |                 oOrigin(0) is the X coordinate of the origin
                |                 oOrigin(1) is the Y coordinate of the origin
                |                 oOrigin(2) is the Z coordinate of the origin 
                | 
                |     Example:
                | 
                |              This example retrieves the origin of the 3D viewpoint of the
                |              NewAnnotatedView annotated view.
                |             
                | 
                |             Dim origin(2)
                |             NewAnnotatedView.GetOrigin origin

        :param tuple o_origin:
        :return: None
        :rtype: None
        """
        return self.annotated_view.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(annotated_view)
        # #     Dim oOrigin (2)
        # #     annotated_view.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_sight_direction(self, o_sight: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSightDirection(CATSafeArrayVariant oSight)
                | 
                |     Retrieves the components of the sight direction of the 3D viewpoint of the
                |     annotated view. The sight direction is the line that passes by the origin of
                |     the viewpoint and by the target.
                | 
                |     Parameters:
                | 
                |         oSight
                |             The components of the viewpoint sight direction expressed as an
                |             array of 3 variants are:
                | 
                |                 oSight(0) is the X component of the sight
                |                 direction
                |                 oSight(1) is the Y component of the sight
                |                 direction
                |                 oSight(2) is the Z component of the sight direction
                |                 
                | 
                |     Example:
                | 
                |              This example retrieves the sight direction of the NewAnnotatedView
                |              annotated view.
                |             
                | 
                |             Dim sight(2)
                |             NewAnnotatedView.GetSightDirection sight

        :param tuple o_sight:
        :return: None
        :rtype: None
        """
        return self.annotated_view.GetSightDirection(o_sight)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_sight_direction'
        # # vba_code = """
        # # Public Function get_sight_direction(annotated_view)
        # #     Dim oSight (2)
        # #     annotated_view.GetSightDirection oSight
        # #     get_sight_direction = oSight
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_up_direction(self, o_up: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetUpDirection(CATSafeArrayVariant oUp)
                | 
                |     Retrieves the components of the up direction of the 3D viewpoint of the
                |     annotated view.
                | 
                |     Parameters:
                | 
                |         oUp
                |             The components of the viewpoint up direction expressed as an array
                |             of 3 variants are:
                | 
                |                 oUp(0) is the X component of the up direction
                |                 oUp(1) is the Y component of the up direction
                |                 oUp(2) is the Z component of the up direction 
                | 
                |     Example:
                | 
                |              This example retrieves the up direction of the NewAnnotatedView
                |              annotated view.
                |             
                | 
                |             Dim up(2)
                |             NewAnnotatedView.GetUpDirection up

        :param tuple o_up:
        :return: None
        :rtype: None
        """
        return self.annotated_view.GetUpDirection(o_up)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_up_direction'
        # # vba_code = """
        # # Public Function get_up_direction(annotated_view)
        # #     Dim oUp (2)
        # #     annotated_view.GetUpDirection oUp
        # #     get_up_direction = oUp
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Update()
                | 
                |     Updates the annotated view: that is to take into account all modifications
                |     which occur since last update.
                | 
                |     Example:
                | 
                |              This example updates the NewAnnotatedView annotated
                |              view.
                |             
                | 
                |             NewAnnotatedView.Update

        :return: None
        :rtype: None
        """
        return self.annotated_view.Update()

    def __repr__(self):
        return f'AnnotatedView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING
from pycatia.funct_system_interfaces.functional_object import FunctionalObject

if TYPE_CHECKING:
    from pycatia.funct_system_interfaces.functional_description import FunctionalDescription


class FunctionalObjectProxy(FunctionalObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalElement
                |                         CATFunctSystemItf.FunctionalPosition
                |                             CATFunctSystemItf.FunctionalObject
                |                                 FunctionalObjectProxy
                | 
                | The interface to access a Functional ObjectProxy.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_object_proxy = com_object

    @property
    def description(self) -> 'FunctionalDescription':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As FunctionalDescription (Read Only)
                | 
                |     Get the description attached to the proxi.

        :return: FunctionalDescription
        :rtype: FunctionalDescription
        """

        return FunctionalDescription(self.functional_object_proxy.Description)

    def set_description(self, i_desc: 'FunctionalDescription') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_Description(FunctionalDescription iDesc)
                | 
                |     set the description attached to the proxi.

        :param FunctionalDescription i_desc:
        :return: None
        :rtype: None
        """
        return self.functional_object_proxy.set_Description(i_desc.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_description'
        # # vba_code = """
        # # Public Function set_description(functional_object_proxy)
        # #     Dim iDesc (2)
        # #     functional_object_proxy.set_Description iDesc
        # #     set_description = iDesc
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FunctionalObjectProxy(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.dress_up_shape import DressUpShape


class Fillet(DressUpShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             Fillet
                | 
                | Represents the fillet shape.
                | It is the base object for face fillets and edge fillets.
                | 
                | See also:
                |     FaceFillet, EdgeFillet
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fillet = com_object

    @property
    def fillet_boundary_relimitation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FilletBoundaryRelimitation() As
                | CatFilletBoundaryRelimitation
                | 
                |     Returns or sets the fillet boundary relimitation mode. This boundary
                |     relimitation mode is used when computing the fillet.
                | 
                |     Example:
                |         The following example returns in mode the fillet boundary relimitation
                |         mode of the firstFillet fillet, and then sets it to
                |         catMinimumFilletBoundaryRelimitation, so that the fillet expands up to the
                |         limits of the smallest shell:
                | 
                |          Set mode = firstFillet.FilletBoundaryRelimitation
                |          Set FirstFillet.FilletBoundaryRelimitation = catMinimumFilletBoundaryRelimitation

        :return: int
        :rtype: int
        """

        return self.fillet.FilletBoundaryRelimitation

    @fillet_boundary_relimitation.setter
    def fillet_boundary_relimitation(self, value: int):
        """
        :param int value:
        """

        self.fillet.FilletBoundaryRelimitation = value

    @property
    def fillet_trim_support(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FilletTrimSupport() As CatFilletTrimSupport
                | 
                |     Returns or sets the fillet Trim Support mode. This Trim Support mode is
                |     used when computing the fillet.
                | 
                |     Example:
                |         The following example returns in mode the fillet Trim Support mode of
                |         the firstFillet fillet, and then sets it to catMinimumFilletTrimSupport, so
                |         that the fillet expands up to the limits of the smallest
                |         shell:
                | 
                |          Set mode = firstFillet.FilletTrimSupport
                |          Set FirstFillet.FilletTrimSupport = catNoTrimFilletSupport

        :return: int
        :rtype: int
        """

        return self.fillet.FilletTrimSupport

    @fillet_trim_support.setter
    def fillet_trim_support(self, value: int):
        """
        :param int value:
        """

        self.fillet.FilletTrimSupport = value

    def __repr__(self):
        return f'Fillet(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DocumentationSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DocumentationSettingAtt
                | 
                | Setting controller for the Help property tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of the documentation settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.documentation_setting_att = com_object

    @property
    def companion_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CompanionPath() As CATBSTR
                | 
                |     Returns the User Companion location (path) parameter.

        :return: str
        :rtype: str
        """

        return self.documentation_setting_att.CompanionPath

    @companion_path.setter
    def companion_path(self, value: str):
        """
        :param str value:
        """

        self.documentation_setting_att.CompanionPath = value

    @property
    def doc_language(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DocLanguage() As long
                | 
                |     Returns the technical documentation language parameter.

        :return: int
        :rtype: int
        """

        return self.documentation_setting_att.DocLanguage

    @doc_language.setter
    def doc_language(self, value: int):
        """
        :param int value:
        """

        self.documentation_setting_att.DocLanguage = value

    @property
    def priority(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Priority() As CATDocContextualPriority
                | 
                |     Returns the contextual priority parameter.

        :return: int
        :rtype: int
        """

        return self.documentation_setting_att.Priority

    @priority.setter
    def priority(self, value: int):
        """
        :param int value:
        """

        self.documentation_setting_att.Priority = value

    @property
    def technical_documentation_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TechnicalDocumentationPath() As CATBSTR
                | 
                |     Returns the technical documentation location (path) parameter.

        :return: str
        :rtype: str
        """

        return self.documentation_setting_att.TechnicalDocumentationPath

    @technical_documentation_path.setter
    def technical_documentation_path(self, value: str):
        """
        :param str value:
        """

        self.documentation_setting_att.TechnicalDocumentationPath = value

    def get_companion_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCompanionPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the User Companion location
                |     parameter.
                |     Role:Retrieves the state of the User Companion location parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.documentation_setting_att.GetCompanionPathInfo(io_admin_level, io_locked)

    def get_doc_language_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDocLanguageInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the technical documentation language
                |     parameter.
                |     Role:Retrieves the state of the technical documentation language parameter
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.documentation_setting_att.GetDocLanguageInfo(io_admin_level, io_locked)

    def get_priority_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPriorityInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the contextual priority
                |     parameter.
                |     Role:Retrieves the state of the contextual priority parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.documentation_setting_att.GetPriorityInfo(io_admin_level, io_locked)

    def get_technical_documentation_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTechnicalDocumentationPathInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the technical documentation location
                |     parameter.
                |     Role:Retrieves the state of the technical documentation location parameter
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.documentation_setting_att.GetTechnicalDocumentationPathInfo(io_admin_level, io_locked)

    def set_companion_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCompanionPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the User Companion location parameter.
                |     Role:Locks or unlocks the User Companion location parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.documentation_setting_att.SetCompanionPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_companion_path_lock'
        # # vba_code = """
        # # Public Function set_companion_path_lock(documentation_setting_att)
        # #     Dim iLocked (2)
        # #     documentation_setting_att.SetCompanionPathLock iLocked
        # #     set_companion_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_doc_language_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDocLanguageLock(boolean iLocked)
                | 
                |     Locks or unlocks the technical documentation language
                |     parameter.
                |     Role:Locks or unlocks the technical documentation language parameter if it
                |     is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.documentation_setting_att.SetDocLanguageLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_doc_language_lock'
        # # vba_code = """
        # # Public Function set_doc_language_lock(documentation_setting_att)
        # #     Dim iLocked (2)
        # #     documentation_setting_att.SetDocLanguageLock iLocked
        # #     set_doc_language_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_priority_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPriorityLock(boolean iLocked)
                | 
                |     Locks or unlocks the contextual priority parameter.
                |     Role:Locks or unlocks the contextual priority parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.documentation_setting_att.SetPriorityLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_priority_lock'
        # # vba_code = """
        # # Public Function set_priority_lock(documentation_setting_att)
        # #     Dim iLocked (2)
        # #     documentation_setting_att.SetPriorityLock iLocked
        # #     set_priority_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_technical_documentation_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTechnicalDocumentationPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the technical documentation location
                |     parameter.
                |     Role:Locks or unlocks the technical documentation location parameter if it
                |     is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.documentation_setting_att.SetTechnicalDocumentationPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_technical_documentation_path_lock'
        # # vba_code = """
        # # Public Function set_technical_documentation_path_lock(documentation_setting_att)
        # #     Dim iLocked (2)
        # #     documentation_setting_att.SetTechnicalDocumentationPathLock iLocked
        # #     set_technical_documentation_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DocumentationSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DMUDataFlow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMUDataFlow
                | 
                | Allows the DMU Data Flow Management within the DMU Navigator
                | environment.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dmu_data_flow = com_object

    def cache_export(self, i_directory: str, i_prefix: str, i_data: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CacheExport(CATBSTR iDirectory,
                | CATBSTR iPrefix,
                | long iData)
                | 
                |     Exports all documents related to the product in a
                |     directory.
                | 
                |     Parameters:
                | 
                |         iDirectory
                |             The directory that will contain documents. 
                |         iPrefix
                |             The prefix used to save product documents. 
                |         iData
                |             To save geometries.
                | 
                |                 0: no save.
                |                 1: save.

        :param str i_directory:
        :param str i_prefix:
        :param int i_data:
        :return: None
        :rtype: None
        """
        return self.dmu_data_flow.CacheExport(i_directory, i_prefix, i_data)

    def cache_import(self, i_directory: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CacheImport(CATBSTR iDirectory)
                | 
                |     Imports in the cache of marked documents in a directory.
                | 
                |     Parameters:
                | 
                |         iDirectory
                |             The directory that contains marked documents.

        :param str i_directory:
        :return: None
        :rtype: None
        """
        return self.dmu_data_flow.CacheImport(i_directory)

    def collapse(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Collapse()
                | 
                |     Collapse the product by replacing all sub-product by corresponding
                |     components.

        :return: None
        :rtype: None
        """
        return self.dmu_data_flow.Collapse()

    def replace_by_cgr(self, i_directory: str, i_prefix: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceByCGR(CATBSTR iDirectory,
                | CATBSTR iPrefix)
                | 
                |     Replaces all components of the product by the corresponding CGR located in
                |     a directory.
                | 
                |     Parameters:
                | 
                |         iDirectory
                |             The directory that will contain documents. 
                |         iPrefix
                |             The prefix used to save product documents.

        :param str i_directory:
        :param str i_prefix:
        :return: None
        :rtype: None
        """
        return self.dmu_data_flow.ReplaceByCGR(i_directory, i_prefix)

    def save_as_frozen(self, i_directory: str, i_prefix: str, i_data: int, i_cache: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SaveAsFrozen(CATBSTR iDirectory,
                | CATBSTR iPrefix,
                | long iData,
                | long iCache)
                | 
                |     Saves all documents related to the product in a directory.
                | 
                |     Parameters:
                | 
                |         iDirectory
                |             The directory that will contain documents. 
                |         iPrefix
                |             The prefix used to save product documents. 
                |         iData
                |             To save geometries.
                | 
                |                 0: no save.
                |                 1: save. 
                | 
                |         iCache
                |             To cache data.
                | 
                |                 0: no save.
                |                 1: save.

        :param str i_directory:
        :param str i_prefix:
        :param int i_data:
        :param int i_cache:
        :return: None
        :rtype: None
        """
        return self.dmu_data_flow.SaveAsFrozen(i_directory, i_prefix, i_data, i_cache)

    def __repr__(self):
        return f'DmuDataFlow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeBoundary(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeBoundary
                | 
                | Represents the hybrid shape boundary feature object.
                | Role: To access the data of the hybrid shape boundary feature object. This data
                | includes:
                | 
                |     The boundary propagation
                |     The initial element used for the boundary propagation
                |     The boundary support
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeBoundary
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_boundary = com_object

    @property
    def from_(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property From() As Reference
                | 
                |     Removes or sets the ending limit(i.e Limit2) of the boundary

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_boundary.From)

    @from_.setter
    def from_(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_boundary.From = reference.com_object

    @property
    def from_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FromOrientation() As long
                | 
                |     Gets or sets the Ending Limit Orientation (i.e same or inverse)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_boundary.FromOrientation

    @from_orientation.setter
    def from_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_boundary.FromOrientation = value

    @property
    def initial_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InitialElement() As Reference
                | 
                |     Returns or sets the element used to initialize the boundary
                |     propagation.
                |     Sub-element(s) supported (see Boundary object):
                |     BiDimFeatEdge.
                | 
                |     Example:
                |         This example retrieves in InitElem the initial element of the
                |         ShpBoundary hybrid shape boundary feature.
                | 
                |          Dim InitElem As Reference
                |          InitElem = ShpBoundary.InitialElement

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_boundary.InitialElement)

    @initial_element.setter
    def initial_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_boundary.InitialElement = value.com_object

    @property
    def propagation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Propagation() As long
                | 
                |     Returns or sets the boundary propagation.
                |     Legal values: xxxxxxxxxx
                | 
                |     Example:
                |         This example retrieves in Prop the boundary propagation of the
                |         ShpBoundary hybrid shape boundary feature.
                | 
                |          Prop = ShpBoundary.Propagation

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_boundary.Propagation

    @propagation.setter
    def propagation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_boundary.Propagation = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support surface around which the boundary is
                |     computed.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in SupSurf the initial element of the
                |         ShpBoundary hybrid shape boundary feature.
                | 
                |          Dim SupSurf As Reference
                |          SupSurf = ShpBoundary.Support

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_boundary.Support)

    @support.setter
    def support(self, support_reference: Reference):
        """
        :param Reference support_reference:
        """

        self.hybrid_shape_boundary.Support = support_reference.com_object

    @property
    def to(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property To() As Reference
                | 
                |     Removes or sets the starting limit(i.e Limit1) of the boundary

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_boundary.To)

    @to.setter
    def to(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_boundary.To = value.com_object

    @property
    def to_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ToOrientation() As long
                | 
                |     Gets or sets the Starting Limit Orientation (i.e same or inverse)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_boundary.ToOrientation

    @to_orientation.setter
    def to_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_boundary.ToOrientation = value

    def __repr__(self):
        return f'HybridShapeBoundary(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.boolean_shape import BooleanShape


class Trim(BooleanShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.BooleanShape
                |                             Trim
                | 
                | Represents the Trim, or union trim boolean operation.
                | It is performed between a body and the current shape.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.trim = com_object

    def add_face_to_keep(self, i_face_to_keep: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToKeep(Reference iFaceToKeep)
                | 
                |     Adds a new face to be kept (if face is not divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToKeep
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to Keep for the Trim
                |     firstTrim:
                | 
                |      call firstTrim.AddFaceToKeep(face)

        :param Reference i_face_to_keep:
        :return: None
        :rtype: None
        """
        return self.trim.AddFaceToKeep(i_face_to_keep.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_keep'
        # # vba_code = """
        # # Public Function add_face_to_keep(trim)
        # #     Dim iFaceToKeep (2)
        # #     trim.AddFaceToKeep iFaceToKeep
        # #     add_face_to_keep = iFaceToKeep
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_face_to_keep2(self, i_face_to_keep: Reference, i_face_adjacent_for_keep: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToKeep2(Reference iFaceToKeep,
                | Reference iFaceAdjacentForKeep)
                | 
                |     Adds a new face to be kept (if face is divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToKeep
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                |     iFaceAdjacentForKeep
                |         An adjacent face of iFaceToKeep belonging to the other
                |         operand
                |         The following Boundary object is supported: Face.
                | 
                | Example:
                |     The following example adds the new face face to Keep for the Trim
                |     firstTrim:
                | 
                |      call firstTrim.AddFaceToKeep(face)

        :param Reference i_face_to_keep:
        :param Reference i_face_adjacent_for_keep:
        :return: None
        :rtype: None
        """
        return self.trim.AddFaceToKeep2(i_face_to_keep.com_object, i_face_adjacent_for_keep.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_keep2'
        # # vba_code = """
        # # Public Function add_face_to_keep2(trim)
        # #     Dim iFaceToKeep (2)
        # #     trim.AddFaceToKeep2 iFaceToKeep
        # #     add_face_to_keep2 = iFaceToKeep
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_face_to_remove(self, i_face_to_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToRemove(Reference iFaceToRemove)
                | 
                |     Adds a new face to be Removed (if face not divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToRemove
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to Remove for the Trim
                |     firstTrim:
                | 
                |      call firstTrim.AddFaceToRemove(face)

        :param Reference i_face_to_remove:
        :return: None
        :rtype: None
        """
        return self.trim.AddFaceToRemove(i_face_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_remove'
        # # vba_code = """
        # # Public Function add_face_to_remove(trim)
        # #     Dim iFaceToRemove (2)
        # #     trim.AddFaceToRemove iFaceToRemove
        # #     add_face_to_remove = iFaceToRemove
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_face_to_remove2(self, i_face_to_remove: Reference, i_face_adjacent_for_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToRemove2(Reference iFaceToRemove,
                | Reference iFaceAdjacentForRemove)
                | 
                |     Adds a new face to be Removed (if face is divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToRemove
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                |     iFaceAdjacentForRemove
                |         An adjacent face of iFaceToRemove belonging to the other
                |         operand
                |         The following Boundary object is supported: Face.
                | 
                | Example:
                |     The following example adds the new face face to Remove for the Trim
                |     firstTrim:
                | 
                |      call firstTrim.AddFaceToRemove(face)

        :param Reference i_face_to_remove:
        :param Reference i_face_adjacent_for_remove:
        :return: None
        :rtype: None
        """
        return self.trim.AddFaceToRemove2(i_face_to_remove.com_object, i_face_adjacent_for_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_remove2'
        # # vba_code = """
        # # Public Function add_face_to_remove2(trim)
        # #     Dim iFaceToRemove (2)
        # #     trim.AddFaceToRemove2 iFaceToRemove
        # #     add_face_to_remove2 = iFaceToRemove
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_keep(self, i_face_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToKeep(Reference iFaceToWithdraw)
                | 
                |     Withdraws an existing Kept face (if face is not divided by operation)
                |     .
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to withdraw
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example withdraws the existing face Kept face from the Trim
                |     firstTrim:
                | 
                |      call firstTrim.WithdrawFaceToKeep(face)

        :param Reference i_face_to_withdraw:
        :return: None
        :rtype: None
        """
        return self.trim.WithdrawFaceToKeep(i_face_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_keep'
        # # vba_code = """
        # # Public Function withdraw_face_to_keep(trim)
        # #     Dim iFaceToWithdraw (2)
        # #     trim.WithdrawFaceToKeep iFaceToWithdraw
        # #     withdraw_face_to_keep = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_keep2(self, i_face_to_withdraw: Reference, i_face_adjacent_for_keep: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToKeep2(Reference iFaceToWithdraw,
                | Reference iFaceAdjacentForKeep)
                | 
                |     Withdraws an existing Kept face (if face is divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to withdraw
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                |     iFaceAdjacentForKeep
                |         An adjacent face of iFaceToKeep belonging to the other
                |         operand
                |         The following Boundary object is supported: Face.
                | 
                | Example:
                |     The following example withdraws the existing face Kept face from the Trim
                |     firstTrim:
                | 
                |      call firstTrim.WithdrawFaceToKeep(face)

        :param Reference i_face_to_withdraw:
        :param Reference i_face_adjacent_for_keep:
        :return: None
        :rtype: None
        """
        return self.trim.WithdrawFaceToKeep2(i_face_to_withdraw.com_object, i_face_adjacent_for_keep.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_keep2'
        # # vba_code = """
        # # Public Function withdraw_face_to_keep2(trim)
        # #     Dim iFaceToWithdraw (2)
        # #     trim.WithdrawFaceToKeep2 iFaceToWithdraw
        # #     withdraw_face_to_keep2 = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_remove(self, i_face_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToRemove(Reference iFaceToWithdraw)
                | 
                |     Withdraws an existing Removed face (if face not divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to withdraw
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example withdraws the existing face Removed face from the
                |     Trim firstTrim:
                | 
                |      call firstTrim.WithdrawFaceToRemove(face)

        :param Reference i_face_to_withdraw:
        :return: None
        :rtype: None
        """
        return self.trim.WithdrawFaceToRemove(i_face_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_remove'
        # # vba_code = """
        # # Public Function withdraw_face_to_remove(trim)
        # #     Dim iFaceToWithdraw (2)
        # #     trim.WithdrawFaceToRemove iFaceToWithdraw
        # #     withdraw_face_to_remove = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_remove2(self, i_face_to_withdraw: Reference, i_face_adjacent_for_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToRemove2(Reference iFaceToWithdraw,
                | Reference iFaceAdjacentForRemove)
                | 
                |     Withdraws an existing Removed face (if face is divided by
                |     operation).
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to withdraw
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                |     iFaceAdjacentForRemove
                |         An adjacent face of iFaceToRemove belonging to the other
                |         operand
                |         The following Boundary object is supported: Face.
                | 
                | Example:
                |     The following example withdraws the existing face Removed face from the
                |     Trim firstTrim:
                | 
                |      call firstTrim.WithdrawFaceToRemove(face)

        :param Reference i_face_to_withdraw:
        :param Reference i_face_adjacent_for_remove:
        :return: None
        :rtype: None
        """
        return self.trim.WithdrawFaceToRemove2(i_face_to_withdraw.com_object, i_face_adjacent_for_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_remove2'
        # # vba_code = """
        # # Public Function withdraw_face_to_remove2(trim)
        # #     Dim iFaceToWithdraw (2)
        # #     trim.WithdrawFaceToRemove2 iFaceToWithdraw
        # #     withdraw_face_to_remove2 = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Trim(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.in_interfaces.camera import Camera
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.in_interfaces.viewer_2d import Viewer2D
    from pycatia.in_interfaces.viewer_3d import Viewer3D


class Viewer(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Viewer
                | 
                | Represents the viewer.
                | The viewer is the object that makes your objects display on the
                | screen.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.viewer = com_object

    @property
    def full_screen(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FullScreen() As boolean
                | 
                |     Returns or sets the state of a viewer to occupy the whole
                |     screen.
                |     True if the viewer occupies the whole screen.
                | 
                |     Example:
                |         This example retrieves in IsFullScreen whether the MyViewer viewer
                |         occupies the whole screen.
                | 
                |          IsFullScreen = MyViewer.FullScreen

        :return: bool
        :rtype: bool
        """

        return self.viewer.FullScreen

    @full_screen.setter
    def full_screen(self, value: bool):
        """
        :param bool value:
        """

        self.viewer.FullScreen = value

    @property
    def height(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Height() As long (Read Only)
                | 
                |     Returns the viewer's height, in pixels.
                | 
                |     Example:
                |         This example retrieves the height of the MyViewer
                |         viewer.
                | 
                |          h = MyViewer.Height

        :return: int
        :rtype: int
        """

        return self.viewer.Height

    @property
    def width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Width() As long (Read Only)
                | 
                |     Returns the viewer's width, in pixels.
                | 
                |     Example:
                |         This example retrieves the width of the MyViewer
                |         viewer.
                | 
                |          w = MyViewer.Width

        :return: int
        :rtype: int
        """

        return self.viewer.Width

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Activate()
                | 
                |     Activates the viewer in the window.
                | 
                |     Example:
                |         This example activates Viewers(1) in the window
                |         MyWindow.
                | 
                |          MyWindow.Viewers(1).Activate()

        :return: None
        :rtype: None
        """
        return self.viewer.Activate()

    def capture_to_file(self, i_format: int, i_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CaptureToFile(CatCaptureFormat iFormat,
                | CATBSTR iFile)
                | 
                |     Captures the actually displayed scene by the viewer as an image, and stores
                |     the image in a file. Clipped parts of the scene are also clipped in the
                |     captured image. Images can be captured as CGM, EMF, TIFF, TIFF Greyscale, BMP,
                |     and JPEG images.
                | 
                |     Parameters:
                | 
                |         iFormat
                |             The format in which the image will be created 
                |         iFile
                |             The full pathname of the file into which you want to store the
                |             captured image 
                |         Example:
                |             This example captures the displayed part of the MyViewer viewer as
                |             a BMP image, and stores it in the e:\\MyImage.bmp
                |             file.
                | 
                |              MyViewer.CaptureToFile catCaptureFormatBMP, "e:\\MyImage.bmp"

        :param int i_format:
        :param str i_file:
        :return: None
        :rtype: None
        """
        return self.viewer.CaptureToFile(i_format, i_file)

    def get_background_color(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetBackgroundColor(CATSafeArrayVariant color)
                | 
                |     Gets the viewer's background color. The color is expressed in the RGB color
                |     mode, as a triplet of coordinates ranging from 0 to 1 for the red, green, and
                |     blue colors respectively.
                | 
                |     Example:
                |         This example gets the background color of the MyViewer
                |         viewer.
                | 
                |          Dim color(2)
                |          MyViewer.GetBackgroundColor color

        :param tuple color:
        :return: None
        :rtype: None
        """
        vba_function_name = 'get_background_color'
        vba_code = """
        Public Function get_background_color(viewer)
            Dim color (2)
            viewer.GetBackgroundColor color
            get_background_color = color
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_viewer_2d(self) -> 'Viewer2D':
        from pycatia.in_interfaces.viewer_2d import Viewer2D

        return Viewer2D(self.viewer)

    def create_viewer_3d(self) -> 'Viewer3D':
        from pycatia.in_interfaces.viewer_3d import Viewer3D

        return Viewer3D(self.viewer)

    def new_camera(self) -> Camera:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func NewCamera() As Camera
                | 
                |     Creates a new camera from the viewpoint of the viewer.
                | 
                |     Example:
                |         This example creates the MyCamera new camera by using the current
                |         viewpoint of the MyViewer viewer.
                | 
                |          Dim MyCamera As Camera
                |          Set MyCamera = MyViewer.NewCamera()

        :return: Camera
        :rtype: Camera
        """
        return Camera(self.viewer.NewCamera())

    def put_background_color(self, color: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutBackgroundColor(CATSafeArrayVariant color)
                | 
                |     Sets the viewer's background color. The color is expressed in the RGB color
                |     mode, as a triplet of coordinates ranging from 0 to 1 for the red, green, and
                |     blue colors respectively.
                | 
                |     Example:
                |         This example sets the background color of the MyViewer viewer to blue,
                |         that is the color with (0.,0.,1.) coordinates
                | 
                |          MyViewer.PutBackgroundColor Array(0, 0, 1)

        :param tuple color:
        :return: None
        :rtype: None
        """
        return self.viewer.PutBackgroundColor(color)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_background_color'
        # # vba_code = """
        # # Public Function put_background_color(viewer)
        # #     Dim color (2)
        # #     viewer.PutBackgroundColor color
        # #     put_background_color = color
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reframe(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Reframe()
                | 
                |     Reframes the viewer's contents (Fits all in). Reframing means that the
                |     viewer's contents is zoomed in or out to enable every object of the scene to be
                |     displayed in such a way that most of the space available in the viewer is used,
                |     just leaving a thin empty strip around the scene.
                | 
                |     Example:
                |         This example reframes the contents of the MyViewer
                |         viewer.
                | 
                |          MyViewer.Reframe()

        :return: None
        :rtype: None
        """
        return self.viewer.Reframe()

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Update()
                | 
                |     Updates the viewer's contents. Since the viewer is not automatically
                |     updated after a viewpoint modification (for performance reasons), it must be
                |     explicitely redrawn when needed.
                | 
                |     Example:
                |         This example updates the contents of the MyViewer
                |         viewer.
                | 
                |          MyViewer.Update()

        :return: None
        :rtype: None
        """
        return self.viewer.Update()

    def zoom_in(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ZoomIn()
                | 
                |     Zooms in the viewer's contents.
                | 
                |     Example:
                |         This example zooms in the contents of the MyViewer
                |         viewer.
                | 
                |          MyViewer.ZoomIn()

        :return: None
        :rtype: None
        """
        return self.viewer.ZoomIn()

    def zoom_out(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ZoomOut()
                | 
                |     Zooms out the viewer's contents.
                | 
                |     Example:
                |         This example zooms out the contents of the MyViewer
                |         viewer.
                | 
                |          MyViewer.ZoomOut()

        :return: None
        :rtype: None
        """
        return self.viewer.ZoomOut()

    def __repr__(self):
        return f'Viewer(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.tps_interfaces.annotations import Annotations


class DatumSimple(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DatumSimple
                | 
                | Interface for Simple Datum TPS (datum entity).
                | TPS for Technological Product Specifications.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.datum_simple = com_object

    @property
    def label(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Label() As CATBSTR
                | 
                |     Retrieves or sets Label.

        :return: str
        :rtype: str
        """

        return self.datum_simple.Label

    @label.setter
    def label(self, value: str):
        """
        :param str value:
        """

        self.datum_simple.Label = value

    @property
    def targets(self) -> 'Annotations':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Targets() As Annotations (Read Only)
                | 
                |     Retrieves a CATITPSList to read the list of datum target. All objects of
                |     the list adhere to CATITPSDatumTarget.

        :return: Annotations
        :rtype: Annotations
        """
        from pycatia.tps_interfaces.annotations import Annotations
        return Annotations(self.datum_simple.Targets)

    def __repr__(self):
        return f'DatumSimple(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DefaultAnnotation(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DefaultAnnotation
                | 
                | This interface is used to get information about default
                | annotation.
                | Ther is two kinds of default annotation : - with a manual selection - with a selection automatic
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.default_annotation = com_object

    @property
    def link_wi_geom_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LinkWiGeomType() As CATBSTR (Read Only)
                | 
                |     Get the type of link between the default annotation and the geometry.
                |     Return E_FAIL if the annotation is not a default one.
                | 
                |     Parameters:
                | 
                |         oLinkWiGeom
                |             Type of link.

        :return: str
        :rtype: str
        """

        return self.default_annotation.LinkWiGeomType

    @property
    def search_algo_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SearchAlgoType() As CATBSTR (Read Only)
                | 
                |     Get the type of search algo to find geometry on which the annotation apply
                |     to. Return E_FAIL if the annotation is not a default one.
                | 
                |     Parameters:
                | 
                |         oAlgo
                |             Type of algo.

        :return: str
        :rtype: str
        """

        return self.default_annotation.SearchAlgoType

    def is_in_automatic_search_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsInAutomaticSearchMode() As boolean
                | 
                |     Get the type of search algo Return E_FAIL if the annotation is not a
                |     default one.
                | 
                |     Parameters:
                | 
                |         oIsAutoMode
                |             oIsAutoMode = TRUE if Automatic mode

        :return: bool
        :rtype: bool
        """
        return self.default_annotation.IsInAutomaticSearchMode()

    def __repr__(self):
        return f'DefaultAnnotation(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.product_structure_interfaces.product import Product


class ProductDocument(Document):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         ProductDocument
                | 
                | Represents the Document object for product structures.
                | When a ProductDocument is created, a root product is created whose parent is
                | the ProductDocument object. Its default name is RootProduct, which can be
                | overwritten thanks to the the AnyObject.Name property. This root product is at
                | the top of the product tree structure contained in the document. It has no
                | difference with the other contained products, except it has no father product
                | in the product tree structure within the document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.product_document = com_object

    @property
    def product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Product() As Product (Read Only)
                | 
                |     Returns the root product.
                | 
                |     Example:
                | 
                |           This example retrieves the root product of the
                |           MyProductDoc
                |          ProductDocument in RootProduct.
                |          
                | 
                |          Dim RootProduct As Product
                |          Set RootProduct = MyProductDoc.Product

        :return: Product
        :rtype: Product
        """

        return Product(self.product_document.Product)

    def __repr__(self):
        return f'ProductDocument(name="{ self.name }")'



from pycatia.cat_mat_interfaces.material_document import MaterialDocument
from pycatia.drafting_interfaces.drawing_document import DrawingDocument
from pycatia.mec_mod_interfaces.part_document import PartDocument
from pycatia.product_structure_interfaces.product_document import ProductDocument
from pycatia.funct_system_interfaces.functional_document import FunctionalDocument

document_type = {
    "CATPart": PartDocument,
    "CATProduct": ProductDocument,
    "CATDrawing": DrawingDocument,
    "CATMaterial": MaterialDocument,
    "CATSystem": FunctionalDocument
}



# ! /usr/bin/python3.6

def check_type(object_, type_):
    """
    
    Function to check the object type and raise an error if the wrong expected type is supplied.

    :param object_: Any python object.
    :param type_: Any python or pycatia type.
    """

    if not isinstance(object_, type_):
        raise TypeError(f'Wrong type. Expected type {type_}.')

    pass



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.light_sources import LightSources
from pycatia.in_interfaces.viewer import Viewer
from pycatia.in_interfaces.viewpoint_3d import Viewpoint3D


class Viewer3D(Viewer):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Viewer
                |                         Viewer3D
                | 
                | Represents a 3D viewer.
                | The 3D viewer aggregates a 3D viewpoint to display a 3D scene. In addition, the
                | Viewer3D object manages the lighting, the depth effects, the navigation style,
                | and the rendering mode.
                | 
                | See also:
                |     Viewpoint3D, CatLightingMode, CatNavigationStyle, CatRenderingMode
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.viewer_3d = com_object

    @property
    def clipping_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ClippingMode() As CatClippingMode
                | 
                |     Returns or sets the clipping mode.
                | 
                |     Example:
                |         This example sets the depth effect for the My3DViewer 3D viewer to
                |         catClippingModeNearAndFar.
                | 
                |          My3DViewer.ClippingMode = catClippingModeNearAndFar

        :return: int
        :rtype: int
        """

        return self.viewer_3d.ClippingMode

    @clipping_mode.setter
    def clipping_mode(self, value: int):
        """
        :param int value:
        """

        self.viewer_3d.ClippingMode = value

    @property
    def far_limit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FarLimit() As double
                | 
                |     Returns or sets the far limit for the far clipping plane. The distance is
                |     measured from the eye location, that is the origin of the viewpoint, and is
                |     expressed in model unit. The far clipping plane is available with the
                |     catClippingModeFar and catClippingModeNearAndFar values of the CatClippingMode
                |     enumeration only.
                | 
                |     Example:
                |         This example sets the far limit for the far clipping plane of the
                |         My3DViewer 3D viewer to 150 model units.
                | 
                |          My3DViewer.FarLimit = 150

        :return: float
        :rtype: float
        """

        return self.viewer_3d.FarLimit

    @far_limit.setter
    def far_limit(self, value: float):
        """
        :param float value:
        """

        self.viewer_3d.FarLimit = value

    @property
    def foggy(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Foggy() As boolean
                | 
                |     Returns or sets the fog mode. Useful when clipping is
                |     enabled.
                | 
                |     Example:
                |         This example sets the fog on for the My3DViewer 3D
                |         viewer:
                | 
                |          My3DViewer.Foggy = True

        :return: bool
        :rtype: bool
        """

        return self.viewer_3d.Foggy

    @foggy.setter
    def foggy(self, value: bool):
        """
        :param bool value:
        """

        self.viewer_3d.Foggy = value

    @property
    def ground(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Ground() As boolean
                | 
                |     Returns or sets the ground displaying mode.
                | 
                |     Example:
                |         This example makes the ground visible for the My3DViewer 3D
                |         viewer:
                | 
                |          My3DViewer.Ground = True

        :return: bool
        :rtype: bool
        """

        return self.viewer_3d.Ground

    @ground.setter
    def ground(self, value: bool):
        """
        :param bool value:
        """

        self.viewer_3d.Ground = value

    @property
    def light_sources(self) -> LightSources:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LightSources() As LightSources (Read Only)
                | 
                |     Returns the viewer's light source collection.
                | 
                |     Example:
                |         This example retrieves the light source collection for the My3DViewer
                |         3D viewer in VPLightSources.
                | 
                |          Set VPLightSources = My3DViewer.LightSources

        :return: LightSources
        :rtype: LightSources
        """

        return LightSources(self.viewer_3d.LightSources)

    @property
    def lighting_intensity(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LightingIntensity() As double
                | 
                |     Returns or sets the lighting intensity. The lighting intensity ranges
                |     between 0 and 1.
                | 
                |     Example:
                |         This example sets the lighting intensity for the My3DViewer 3D viewer
                |         to 0.35.
                | 
                |          My3DViewer.LightingIntensity = 0.35

        :return: float
        :rtype: float
        """

        return self.viewer_3d.LightingIntensity

    @lighting_intensity.setter
    def lighting_intensity(self, value: float):
        """
        :param float value:
        """

        self.viewer_3d.LightingIntensity = value

    @property
    def lighting_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LightingMode() As CatLightingMode
                | 
                |     Returns or sets the lighting mode.
                | 
                |     Example:
                |         This example sets the lighting mode for the My3DViewer 3D viewer to
                |         catInfiniteLightSource.
                | 
                |          My3DViewer.LightingMode = catInfiniteLightSource

        :return: int
        :rtype: int
        """

        return self.viewer_3d.LightingMode

    @lighting_mode.setter
    def lighting_mode(self, value: int):
        """
        :param int value:
        """

        self.viewer_3d.LightingMode = value

    @property
    def navigation_style(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NavigationStyle() As CatNavigationStyle
                | 
                |     Returns or sets the navigation style.
                | 
                |     Example:
                |         This example sets the navigation style for the My3DViewer 3D viewer to
                |         catNavigationWalk.
                | 
                |          My3DViewer.NavigationStyle = catNavigationWalk

        :return: int
        :rtype: int
        """

        return self.viewer_3d.NavigationStyle

    @navigation_style.setter
    def navigation_style(self, value: int):
        """
        :param int value:
        """

        self.viewer_3d.NavigationStyle = value

    @property
    def near_limit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NearLimit() As double
                | 
                |     Returns or sets the near limit for the near clipping plane. The distance is
                |     measured from the eye location, that is the origin of the viewpoint, and is
                |     expressed in model unit. The near clipping plane is available with the
                |     catClippingModeNear and catClippingModeNearAndFar values of the CatClippingMode
                |     enumeration only.
                | 
                |     Example:
                |         This example sets the near limit for the near clipping plane of the
                |         My3DViewer 3D viewer to 75 model units.
                | 
                |          My3DViewer.NearLimit = 75

        :return: float
        :rtype: float
        """

        return self.viewer_3d.NearLimit

    @near_limit.setter
    def near_limit(self, value: float):
        """
        :param float value:
        """

        self.viewer_3d.NearLimit = value

    @property
    def rendering_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RenderingMode() As CatRenderingMode
                | 
                |     Returns or sets the rendering mode.
                | 
                |     Example:
                |         This example sets the rendering mode for the My3DViewer 3D viewer to
                |         catRenderShadingWithEdges.
                | 
                |          My3DViewer.RenderingMode = catRenderShadingWithEdges

        :return: int
        :rtype: int
        """

        return self.viewer_3d.RenderingMode

    @rendering_mode.setter
    def rendering_mode(self, value: int):
        """
        :param int value:
        """

        self.viewer_3d.RenderingMode = value

    @property
    def viewpoint_3d(self) -> Viewpoint3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Viewpoint3D() As Viewpoint3D
                | 
                |     Returns or sets the 3D viewpoint of a 3D viewer.
                | 
                |     Example:
                |         This example retrieves the Nice3DViewpoint 3D viewpoint from the
                |         My3DViewer 3D viewer.
                | 
                |          Dim Nice3DViewpoint As Viewpoint3D
                |          Set Nice3DViewpoint = My3DViewer.Viewpoint3D

        :return: Viewpoint3D
        :rtype: Viewpoint3D
        """

        return Viewpoint3D(self.viewer_3d.Viewpoint3D)

    @viewpoint_3d.setter
    def viewpoint_3d(self, value: Viewpoint3D):
        """
        :param Viewpoint3D value:
        """

        self.viewer_3d.Viewpoint3D = value

    def rotate(self, i_axis: tuple, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Rotate(CATSafeArrayVariant iAxis,
                | double iAngle)
                | 
                |     Applies a rotation. The rotation of iAngle degrees is applied to the
                |     viewer's contents around the axis iAxis (an array of 3 Variants), the invariant
                |     point being the target (ie: Origin +
                |     FocusDistance*SightDirection).
                | 
                |     Example:
                |         This applies a rotation of 10 degrees around the Up Direction to the
                |         contents of the MyViewer3D viewer.
                | 
                |          MyViewer3D.Rotate MyViewer3D.UpDirection, 10

        :param tuple i_axis:
        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.viewer_3d.Rotate(i_axis, i_angle)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'rotate'
        # # vba_code = """
        # # Public Function rotate(viewer_3d)
        # #     Dim iAxis (2)
        # #     viewer_3d.Rotate iAxis
        # #     rotate = iAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def translate(self, i_vector: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Translate(CATSafeArrayVariant iVector)
                | 
                |     Applies a translation. The translation vector is iVector (an array of 3
                |     Variants).
                | 
                |     Example:
                |         This applies a translation along (1, 1, 1) to the contents of the
                |         MyViewer3D viewer.
                | 
                |          MyViewer3D.Translate Array(1, 1, 1)

        :param tuple i_vector:
        :return: None
        :rtype: None
        """
        return self.viewer_3d.Translate(i_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'translate'
        # # vba_code = """
        # # Public Function translate(viewer_3d)
        # #     Dim iVector (2)
        # #     viewer_3d.Translate iVector
        # #     translate = iVector
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Viewer3D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.funct_system_interfaces.funct_actions_groups import FunctActionsGroups
from pycatia.funct_system_interfaces.functional_actions import FunctionalActions
from pycatia.funct_system_interfaces.functional_element import FunctionalElement
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet
from pycatia.funct_system_interfaces.functional_facet_mgr import FunctionalFacetMgr
from pycatia.funct_system_interfaces.functional_objects import FunctionalObjects
from pycatia.funct_system_interfaces.functional_position import FunctionalPosition

if TYPE_CHECKING:
    from pycatia.funct_system_interfaces.functional_variants import FunctionalVariants


class FunctionalDescription(FunctionalElement):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalElement
                |                         FunctionalDescription
                | 
                | The interface to access a Functional Description.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_description = com_object

    @property
    def actions(self) -> FunctionalActions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Actions() As FunctionalActions (Read Only)
                | 
                |     Get the Actions collection.

        :return: FunctionalActions
        :rtype: FunctionalActions
        """

        return FunctionalActions(self.functional_description.Actions)

    @property
    def actions_groups(self) -> FunctActionsGroups:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActionsGroups() As FunctActionsGroups (Read Only)
                | 
                |     Get the ActionsGroups collection.

        :return: FunctActionsGroups
        :rtype: FunctActionsGroups
        """

        return FunctActionsGroups(self.functional_description.ActionsGroups)

    @property
    def objects(self) -> FunctionalObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Objects() As FunctionalObjects (Read Only)
                | 
                |     Get the Objects collection.

        :return: FunctionalObjects
        :rtype: FunctionalObjects
        """

        return FunctionalObjects(self.functional_description.Objects)

    @property
    def variants(self) -> 'FunctionalVariants':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Variants() As FunctionalVariants (Read Only)
                | 
                |     Get the Variants collection.
                | 
                |     (gives a NULL pointer if the description is a itself variant)

        :return: FunctionalVariants
        :rtype: FunctionalVariants
        """

        return FunctionalVariants(self.functional_description.Variants)

    def create_position(self, i_x: float, i_y: float) -> FunctionalPosition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreatePosition(double iX,
                | double iY) As FunctionalPosition
                | 
                |     Create a Position.
                | 
                |     To create actions pointing to NULL

        :param float i_x:
        :param float i_y:
        :return: FunctionalPosition
        :rtype: FunctionalPosition
        """
        return FunctionalPosition(self.functional_description.CreatePosition(i_x, i_y))

    def get_facet(self, i_fm: FunctionalFacetMgr) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacet(FunctionalFacetMgr iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param FunctionalFacetMgr i_fm:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_description.GetFacet(i_fm.com_object))

    def get_facet_by_name(self, i_fm: str) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacetByName(CATBSTR iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param str i_fm:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_description.GetFacetByName(i_fm))

    def search_facet(self, i_fm: FunctionalFacetMgr, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacet(FunctionalFacetMgr iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param FunctionalFacetMgr i_fm:
        :param bool i_create_if_necessary:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_description.SearchFacet(i_fm.com_object, i_create_if_necessary))

    def search_facet_by_name(self, i_fm: str, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacetByName(CATBSTR iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param str i_fm:
        :param bool i_create_if_necessary:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_description.SearchFacetByName(i_fm, i_create_if_necessary))

    def unlock(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Unlock()
                | 
                |     Unlock.
                | 
                |     To remove the protection against modifications.

        :return: None
        :rtype: None
        """
        return self.functional_description.Unlock()

    def __repr__(self):
        return f'FunctionalDescription(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.in_interfaces.document import Document
from pycatia.mec_mod_interfaces.part import Part
from pycatia.product_structure_interfaces.product import Product


class PartDocument(Document):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Document
                |                         PartDocument
                |
                | Represents the Document object for parts.
                |
                | Role: When a PartDocument object is created, a Part object is also created.
                | This Part object is the root object of the Part structure.
                |
                | A reference Product object is also created in each PartDocument. It is used to
                | access Publications, PartNumber.
                |
                | See also:
                |     Product, Part

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.part_document = com_object

    @property
    def part(self) -> Part:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Part() As Part (Read Only)
                | 
                |     Returns the root Part object from the current part
                |     document.
                | 
                |     Example:
                |         The following example retrieves in RootPart the root Part object of the
                |         active document, assumed to be a part document:
                | 
                |          Set RootPart = CATIA.ActiveDocument.Part

        :return: Part
        :rtype: Part
        """

        return Part(self.part_document.Part)

    @property
    def product(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Product() As Product (Read Only)
                | 
                |     Returns the root Product object from the current part
                |     document.
                | 
                |     Example:
                |         The following example retrieves in RootProd the root Product object of
                |         the active document, assumed to be a part document:
                | 
                |          Set RootProd = CATIA.ActiveDocument.Part

        :return: Product
        :rtype: Product
        """

        return Product(self.part_document.Product)

    def __repr__(self):
        return f'PartDocument(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.in_interfaces.file_component import FileComponent
from pycatia.in_interfaces.files import Files

if TYPE_CHECKING:
    from pycatia.in_interfaces.folders import Folders

class Folder(FileComponent):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.FileComponent
                |                         Folder
                | 
                | Represents the folder object.
                | It allows you to manipulate folders and gives access to information about
                | them.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.folder = com_object

    @property
    def files(self) -> Files:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Files() As Files (Read Only)
                | 
                |     Returns the file collection of the folder.
                | 
                |     Example:
                |         This example retrieves in TestFiles the file collection of the folder
                |         TestFolder.
                | 
                |          Dim TestFiles As Files
                |          Set TestFiles = TestFolder.Files

        :return: Files
        :rtype: Files
        """

        return Files(self.folder.Files)

    @property
    def sub_folders(self) -> 'Folders':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SubFolders() As Folders (Read Only)
                | 
                |     Returns the folder collection of the folder.
                | 
                |     Example:
                |         This example retrieves in TestSubFolders the folder colection of the
                |         folder TestFolder.
                | 
                |          Dim TestSubFolders As CATIAFolders
                |          Set TestSubFolders = TestFolder.SubFolders

        :return: Folders
        :rtype: Folders
        """
        from pycatia.in_interfaces.folders import Folders
        return Folders(self.folder.SubFolders)

    def __repr__(self):
        return f'Folder(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.cat_mat_interfaces.materials import Materials
from pycatia.system_interfaces.any_object import AnyObject


class MaterialFamily(AnyObject):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     MaterialFamily
            |
            | Represents a Material Family object.
            | This object is used to group Materials objects in a material
            | document.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.material_family = com_object

    @property
    def materials(self) -> Materials:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Materials() As Materials (Read Only)
                |
                |     Returns the material collection object from the current
                |     material family.

        :return: Materials
        :rtype: Materials
        """

        return Materials(self.material_family.Materials)

    def __repr__(self):
        return f'MaterialFamily(name="{self.name}")'
